pub struct Cluster { /* private fields */ }Available on crate feature
actor only.Expand description
A set of Compio workers on which actors are placed.
Implementations
Sourceimpl Cluster
impl Cluster
Sourcepub fn from_dispatcher(dispatcher: Dispatcher) -> Cluster
pub fn from_dispatcher(dispatcher: Dispatcher) -> Cluster
Creates a cluster from a configured dispatcher.
Sourcepub fn spawn<A, F>(
&self,
factory: F,
arguments: <A as Actor>::Arguments,
) -> Spawn<'_, A, F>
pub fn spawn<A, F>( &self, factory: F, arguments: <A as Actor>::Arguments, ) -> Spawn<'_, A, F>
Configures an actor spawn operation.
The return type is a configurable future implementing IntoFuture.
See Spawn for detail.